summaryrefslogtreecommitdiff
path: root/pear/PEAR
diff options
context:
space:
mode:
authorMartin Jansen <mj@php.net>2004-06-18 14:41:01 +0000
committerMartin Jansen <mj@php.net>2004-06-18 14:41:01 +0000
commit6910e6432a8f2f5b05d3b18d559940cbe8e47146 (patch)
tree2b5956522ea8d55ba122e3131a20e5e9bfd7fe4f /pear/PEAR
parent851b6d44754436611d794573999cea5fa5bcfece (diff)
downloadphp-git-6910e6432a8f2f5b05d3b18d559940cbe8e47146.tar.gz
* Replaced the nonexistent word "postfix" with "suffix".
Diffstat (limited to 'pear/PEAR')
-rw-r--r--pear/PEAR/Downloader.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/pear/PEAR/Downloader.php b/pear/PEAR/Downloader.php
index 2bc87f3867..17ad4566a1 100644
--- a/pear/PEAR/Downloader.php
+++ b/pear/PEAR/Downloader.php
@@ -456,9 +456,9 @@ class PEAR_Downloader extends PEAR_Common
if ($version == 0) {
return $this->raiseError("No release with state '$state' found for '$pkgfile'");
}
// invalid postfix passed
} else {
- return $this->raiseError("Invalid postfix '-$version', be sure to pass a valid PEAR ".
+ return $this->raiseError("Invalid suffix '-$version', be sure to pass a valid PEAR ".
"version number or release state");
}
// Guess what to download
@@ -456,9 +456,9 @@ class PEAR_Downloader extends PEAR_Common
return $this->raiseError("No release with state '$state' found for '$pkgfile'");
}
- // invalid postfix passed
+ // invalid suffix passed
} else {